# Generated by Django 3.1.4 on 2021-01-07 13:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('logs', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Report',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_created=True, auto_now_add=True)),
                ('index', models.CharField(max_length=1000)),
                ('status', models.PositiveSmallIntegerField()),
                ('data', models.JSONField(blank=True, null=True)),
                ('text', models.TextField(blank=True, null=True)),
            ],
            options={
                'ordering': ('-created_at', 'index'),
            },
        ),
    ]
